@@ -39,6 +39,7 @@
 #include "message.h"
 #include "csv.h"
 #include "picofont.h"
+#include "sequence.h"
 
 u_int gFontsWidth = 0;
 u_int gFontsHeight = 0;
@@ -597,3 +598,65 @@ void tfont_setup_fontlist(TCapValue* vp)
 	}
 }
 
+void tfont_show_sequence(FILE *tf, const char *en)
+{
+	static const char *table[] = {"G0", "G1", "G2", "G3", NULL};
+	static const char *invokeL[] = {"\017", "\016", "\033n", "\033o"};
+	static const char *invokeR[] = {"", "\033~", "\033}", "\033|"};
+	static const char csr4[] = {ISO_GZD4, ISO_G1D4, ISO_G2D4, ISO_G3D4};
+	static const char csr6[] = {MULE__GZD6, ISO_G1D6, ISO_G2D6, ISO_G3D6};
+	TCsv farg;
+	int ig;
+	int i;
+	const char *g;
+
+	tcsv_init(&farg, en);
+	if (farg.cap != 6) {
+		print_warn("ENCODING : BAD FORMAT : %s\n", en);
+		goto end;
+	}
+	/* ISO-2022 */
+	printf("%s", "\033%@");
+	
+	/* GL */
+	g = tcsv_get_token(&farg);
+	ig = util_search_string(g, table);
+	if (ig == -1) {
+		print_error("ENCODING : GL %s ? (BAD FORMAT)\n", g);
+		goto end;
+	}
+	fprintf(tf, "%s", invokeL[ig]);
+
+	/* GR */
+	g = tcsv_get_token(&farg);
+	ig = util_search_string(g, table);
+	if (ig == -1) {
+		print_error("ENCODING : GR %s ? (BAD FORMAT)\n", g);
+		goto end;
+	}
+	fprintf(tf, "%s", invokeR[ig]);
+
+	/* G0 .. G3 */
+	for (i = 0; i < 4; i++) {
+		TFont *f;
+		u_int n;
+		char c;
+		u_int f1, f2;
+		g = tcsv_get_token(&farg);
+		f = tfont_ary_search(g);
+		if (f == NULL) {
+			print_error("ENCODING : G%d %s ? (BAD FORMAT)\n", i, g);
+			continue;
+		}
+		n = f->fsignature;
+		c = n & 255;
+		f1 = n & TFONT_FT_DOUBLE;
+		f2 = n & TFONT_FT_96CHAR;
+		fprintf(tf, "\033%s%c%c", (f1 ? "$" : ""), 
+			(f2 ? csr6[i] : csr4[i]), c);
+	}
+end:
+	tcsv_final(&farg);
+	return;
+}
+
