@@ -263,7 +263,7 @@ void tcaps_read(TCaps* p, const char *filename)
 		print_strerror_and_exit(filename);
 	}
 
-	print_warn("(**) : Configuration file `%s'\n", filename);
+	print_message("(**) : Configuration file `%s'\n", filename);
 
 	while(fgets(line, MAX_COLS, fp) != NULL) {
 		nl++;
@@ -279,17 +279,17 @@ void tcaps_read(TCaps* p, const char *filename)
 			continue;
 		}
 		if (strchr(line, ':') == NULL) {
-			print_warn("(--) : line %d, `%s'\n", nl, line);
+			print_message("(--) : line %d, `%s'\n", nl, line);
 			continue;
 		}
 		b = tcaps_register(p, line);
 		if (!b) {
-			print_warn("(--) : line %d, `%s'\n", nl, line);
+			print_message("(--) : line %d, `%s'\n", nl, line);
 		} else {
-			print_warn("(**) : line %d, `%s'\n", nl, line);
+			print_message("(**) : line %d, `%s'\n", nl, line);
 		}
 	}
-	print_warn("(**) : total %d lines read.\n", nl);
+	print_message("(**) : total %d lines read.\n", nl);
 
 	fclose(fp);
 }
