@@ -28,12 +28,17 @@
 #ifndef INCLUDE_MAIN_H
 #define INCLUDE_MAIN_H
 
+#include "mytypes.h"
+#include "getcap.h"
+
 typedef struct Raw_TApplication {
 	TBool gOrigVirtualConsoleQ;
 	int gOrigVirtualConsole;
 	TBool gCapsQ;
 	TCaps gCaps;
 	TBool gOptShowHelpQ;
+	TBool gOptQuiet;
+	char* gOptReset;
 	char* gExecShell;
 	char** gExecShellArgv;
     	char* gConfFile;
