@@ -53,6 +53,7 @@ static void tvterm_esc_start(TVterm* p, u_char ch);
 static void tvterm_esc_bracket(TVterm*, u_char);
 static void tvterm_esc_traditional_multibyte_fix(TVterm* p, u_char ch);
 static void tvterm_esc_designate_font(TVterm* p, u_char ch);
+static void tvterm_esc_designate_other_coding_system(TVterm* p, u_char ch);
 static void tvterm_invoke_gx(TVterm* p, TFontSpec* fs, u_int n);
 static void tvterm_re_invoke_gx(TVterm* p, TFontSpec* fs);
 void tvterm_set_window_size(TVterm* p);
@@ -465,6 +466,9 @@ static void tvterm_esc_start(TVterm* p, u_char ch)
 		p->esc = tvterm_esc_traditional_multibyte_fix;
 		p->escSignature = TFONT_FT_DOUBLE;
 		break;
+	case ISO_DOCS:
+		p->esc = tvterm_esc_designate_other_coding_system;
+		break;
 	case ISO_GZD4:
 		ESC_ISO_GnDx(0, TFONT_FT_94CHAR);
 		break;
@@ -880,6 +884,21 @@ static void tvterm_esc_designate_font(TVterm* p, u_char ch)
 	p->esc = NULL;
 }
 
+static void tvterm_esc_designate_other_coding_system(TVterm* p, u_char ch)
+{
+	switch (ch) {
+	case 0x40:
+		/* reset ISO-2022 */
+		break;
+#if 0
+	case 0x47:
+		/* designate and invoke UTF-8 coding */
+		break;
+#endif
+	}
+	p->esc = NULL;
+}
+
 static void tvterm_esc_traditional_multibyte_fix(TVterm* p, u_char ch)
 {
 	if (ch == 0x40 || ch == 0x41 || ch == 0x42) {
